package VMOMI::HostFirewallRuleDirection;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
